/*
 * uart.h - serial hw routines
 *
 * Written by
 *  Christian Vogelgsang <chris@vogelgsang.org>
 *
 * This file is part of dtv2ser.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef UART_H
#define UART_H

#include "global.h"
#include <avr/io.h>

// ========== cvm8board =====================================================

#ifdef HAVE_cvm8board

#include "cvm8board.h"

#define uart_init_extra()   // not required
#define uart_init_rts_cts() cvm8_rts_cts_init()
#define uart_set_cts(x)     cvm8_set_cts(x)
#define uart_get_rts()      cvm8_get_rts()

#endif

// ========== ctboard =======================================================

#ifdef HAVE_ctboard

#include "ctboard.h"

#ifdef USE_XPORT
#define uart_init_extra()   ct_init_mplex(); ct_set_mplex(CT_MPLEX_MCU_XPT_COPY_XPT)
#define uart_init_rts_cts() ct_xport_init_rts_cts()
#define uart_set_cts(x)     ct_xport_set_cts(x)
#define uart_get_rts()      ct_xport_get_rts()
#else
#define uart_init_extra()   ct_init_mplex(); ct_set_mplex(CT_MPLEX_COM_MCU_COPY_COM)
#define uart_init_rts_cts() ct_com_init_rts_cts()
#define uart_set_cts(x)     ct_com_set_cts(x)
#define uart_get_rts()      ct_com_get_rts()
#endif

#endif

void uart_init(void);
void uart_clear_buffer(void);

u08 uart_data_available(void);
u08 uart_transmit_buffer_ready(void);

u08 uart_read(u08 *data);
u08 uart_send(u08 data);

u08 uart_read_with_cts(u08 *data);
u08 uart_send_with_rts(u08 data);

#ifdef UDR0
#define uart_read_direct()  UDR0
#define uart_send_direct(__DATA)  UDR0=__DATA
#else
#define uart_read_direct()  UDR
#define uart_send_direct(__DATA)  UDR=__DATA
#endif

// ----- UART convenience functions -----
// send a c string
u08 uart_send_string(u08 *data);
// send data
u08 uart_send_data(u08 *data,u08 size);
// send a CR+LF
u08 uart_send_crlf(void);

// send a hex byte
u08 uart_send_hex_byte_crlf(u08 data);
// send a hex word
u08 uart_send_hex_word_crlf(u16 data);
// send a hex6 dword
u08 uart_send_hex_dword6_crlf(u32 data); 

#endif
